package com.fjs.scenic.service.ticket;

import java.util.List;

import com.fjs.scenic.entity.order.Orders;
import com.fjs.scenic.entity.order.PlayMan;
import com.fjs.scenic.utils.ReturnResult;

/**
 * 分销系统接口
 * @author Administrator
 *
 */
public interface OtaOrderService {
	public void creatOTAOrder();
	
	public String deleteOTAorder(String order) throws Exception;
	
    public String createPaymentOrder(String idCard,String platTime) ;
    
    public ReturnResult createOrder();
    
    public ReturnResult updateOrderToPayment(String totelPrice,String pwOrderNo);

	public String getProduct();


	public String getOrder(String cytOrderNo) ;


	public String refundTicket(String cytOrderNo,String myOrderNo,String price);

	public String getProductStock();


	public ReturnResult checkorderInfo(Orders order,List<PlayMan> playMans,String goodsId,Integer price,int num);

	/***/
	public String ticketNotice(String param,String method);
	
	

}
